Index | django_redux API Document

# References

## Class Summary

Static Public Class Summary
public | ReduxBridge Bridge between Channels and Redux. |
public | WebSocketBridge Bridge between Channels and plain javascript. |

## Variable Summary

Static Public Variable Summary
public | reduxBridge: ReduxSocketBridge Convenience singleton for `ReduxSocketBridge`. |
public | webSocketBridge: WebSocketBridge Convenience singleton for `WebSocketBridge`. |